# Using Tianocore Edk2 PyTool Extensions (edk2toolext)

## Installing

NOTE: It is suggested to use python virtual environments to avoid dependency pollution and conflicts. [Read More](https://docs.python.org/3/library/venv.html)

Install from pip

```cmd 
pip install --upgrade edk2-pytool-extensions
```

## Using in python code

```python
from edk2toolext.<module> import <class>
```
